@@ -68,6 +68,7 @@ get_binaries() {
     darwin/s390x) BINARIES="golangci-lint" ;;
     freebsd/386) BINARIES="golangci-lint" ;;
     freebsd/amd64) BINARIES="golangci-lint" ;;
+    freebsd/arm64) BINARIES="golangci-lint" ;;
     freebsd/armv6) BINARIES="golangci-lint" ;;
     freebsd/armv7) BINARIES="golangci-lint" ;;
     freebsd/mips64) BINARIES="golangci-lint" ;;
@@ -140,7 +141,7 @@ cat /dev/null <<EOF
 ------------------------------------------------------------------------
 https://github.com/client9/shlib - portable posix shell functions
 Public domain - http://unlicense.org
-https://github.com/client9/shlib/blob/master/LICENSE.md
+https://github.com/client9/shlib/blob/HEAD/LICENSE.md
 but credit (and pull requests) appreciated.
 ------------------------------------------------------------------------
 EOF
@@ -275,13 +276,33 @@ http_download_curl() {
   local_file=$1
   source_url=$2
   header=$3
+
+  # workaround https://github.com/curl/curl/issues/13845
+  curl_version=$(curl --version | head -n 1 | awk '{ print $2 }')
+  if [ "$curl_version" = "8.8.0" ]; then
+    log_debug "http_download_curl curl $curl_version detected"
+    if [ -z "$header" ]; then
+      curl -sL -o "$local_file" "$source_url"
+    else
+      curl -sL -H "$header" -o "$local_file" "$source_url"
+
+      nf=$(cat "$local_file" | jq -r '.error // ""')
+      if  [ ! -z "$nf" ]; then
+        log_debug "http_download_curl received an error: $nf"
+        return 1
+      fi
+    fi
+
+    return 0
+  fi
+
   if [ -z "$header" ]; then
     code=$(curl -w '%{http_code}' -sL -o "$local_file" "$source_url")
   else
     code=$(curl -w '%{http_code}' -sL -H "$header" -o "$local_file" "$source_url")
   fi
   if [ "$code" != "200" ]; then
-    log_debug "http_download_curl received HTTP status $code"
+    log_err "http_download_curl received HTTP status $code"
     return 1
   fi
   return 0
@@ -290,11 +311,24 @@ http_download_wget() {
   local_file=$1
   source_url=$2
   header=$3
+  local wget_output
+  local code
   if [ -z "$header" ]; then
-    wget -q -O "$local_file" "$source_url"
+    wget_output=$(wget --server-response --quiet -O "$local_file" "$source_url" 2>&1)
   else
-    wget -q --header "$header" -O "$local_file" "$source_url"
+    wget_output=$(wget --server-response --quiet --header "$header" -O "$local_file" "$source_url" 2>&1)
   fi
+  local wget_exit=$?
+  if [ $wget_exit -ne 0 ]; then
+    log_err "http_download_wget failed: wget exited with status $wget_exit"
+    return 1
+  fi
+  code=$(echo "$wget_output" | awk '/^  HTTP/{print $2}' | tail -n1)
+  if [ "$code" != "200" ]; then
+    log_err "http_download_wget received HTTP status $code"
+    return 1
+  fi
+  return 0
 }
 http_download() {
   log_debug "http_download $2"
