@@ -2,27 +2,22 @@ package fatcontext
 
 import (
 	"go.augendre.info/fatcontext/pkg/analyzer"
-	"golang.org/x/tools/go/analysis"
 
 	"github.com/golangci/golangci-lint/v2/pkg/config"
 	"github.com/golangci/golangci-lint/v2/pkg/goanalysis"
 )
 
 func New(settings *config.FatcontextSettings) *goanalysis.Linter {
-	a := analyzer.NewAnalyzer()
-
-	cfg := map[string]map[string]any{}
+	var cfg map[string]any
 
 	if settings != nil {
-		cfg[a.Name] = map[string]any{
+		cfg = map[string]any{
 			analyzer.FlagCheckStructPointers: settings.CheckStructPointers,
 		}
 	}
 
-	return goanalysis.NewLinter(
-		a.Name,
-		a.Doc,
-		[]*analysis.Analyzer{a},
-		cfg,
-	).WithLoadMode(goanalysis.LoadModeTypesInfo)
+	return goanalysis.
+		NewLinterFromAnalyzer(analyzer.NewAnalyzer()).
+		WithConfig(cfg).
+		WithLoadMode(goanalysis.LoadModeTypesInfo)
 }
