@@ -11,23 +11,16 @@ import (
 	"github.com/golangci/golangci-lint/v2/pkg/goanalysis"
 )
 
-const linterName = "godox"
-
 func New(settings *config.GodoxSettings) *goanalysis.Linter {
-	analyzer := &analysis.Analyzer{
-		Name: linterName,
-		Doc:  goanalysis.TheOnlyanalyzerDoc,
-		Run: func(pass *analysis.Pass) (any, error) {
-			return run(pass, settings), nil
-		},
-	}
-
-	return goanalysis.NewLinter(
-		linterName,
-		"Detects usage of FIXME, TODO and other keywords inside comments",
-		[]*analysis.Analyzer{analyzer},
-		nil,
-	).WithLoadMode(goanalysis.LoadModeSyntax)
+	return goanalysis.
+		NewLinterFromAnalyzer(&analysis.Analyzer{
+			Name: "godox",
+			Doc:  "Detects usage of FIXME, TODO and other keywords inside comments",
+			Run: func(pass *analysis.Pass) (any, error) {
+				return run(pass, settings), nil
+			},
+		}).
+		WithLoadMode(goanalysis.LoadModeSyntax)
 }
 
 func run(pass *analysis.Pass, settings *config.GodoxSettings) error {
@@ -51,9 +44,14 @@ func run(pass *analysis.Pass, settings *config.GodoxSettings) error {
 		ft := pass.Fset.File(file.Pos())
 
 		for _, i := range messages {
+			msg := strings.TrimRight(i.Message, "\n")
+
+			// https://github.com/matoous/godox/blob/1d6ac9d899726279072e1c4d2b10f1eb52f22878/godox.go#L56
+			index := strings.Index(msg, "Line contains")
+
 			pass.Report(analysis.Diagnostic{
 				Pos:     ft.LineStart(goanalysis.AdjustPos(i.Pos.Line, nonAdjPosition.Line, position.Line)) + token.Pos(i.Pos.Column),
-				Message: strings.TrimRight(i.Message, "\n"),
+				Message: msg[index:],
 			})
 		}
 	}
