@@ -8,7 +8,7 @@ import (
 
 	"github.com/stretchr/testify/require"
 
-	"github.com/golangci/golangci-lint/test/testshared"
+	"github.com/golangci/golangci-lint/v2/test/testshared"
 )
 
 // value: "1"
@@ -30,7 +30,7 @@ func setupTestFix(t *testing.T) []string {
 
 	sourcesDir := filepath.Join(testdataDir, "fix")
 
-	err := exec.Command("cp", "-R", sourcesDir, tmpDir).Run()
+	err := exec.CommandContext(t.Context(), "cp", "-R", sourcesDir, tmpDir).Run()
 	require.NoError(t, err)
 
 	return findSources(t, tmpDir, "in", "*.go")
@@ -66,10 +66,10 @@ func runFix(t *testing.T, extraArgs ...string) {
 			}
 
 			testshared.NewRunnerBuilder(t).
-				WithArgs("--disable-all",
-					"--print-issued-lines=false",
-					"--print-linter-name=false",
-					"--out-format=line-number",
+				WithArgs("--default=none",
+					"--output.text.print-issued-lines=false",
+					"--output.text.print-linter-name=false",
+					"--output.text.path=stdout",
 					"--fix").
 				WithArgs(extraArgs...).
 				WithRunContext(rc).
